import { EditorView, ViewUpdate, PluginValue } from '@codemirror/view';
import * as LSP from 'vscode-languageserver-protocol';
import { CompletionTriggerKind, PublishDiagnosticsParams } from "vscode-languageserver-protocol";
import { CompletionContext, CompletionResult } from '@codemirror/autocomplete';
import { Tooltip } from '@codemirror/tooltip';
interface LSPEventMap {
    'textDocument/publishDiagnostics': LSP.PublishDiagnosticsParams;
}
type Notification = {
    [key in keyof LSPEventMap]: {
        jsonrpc: '2.0';
        id?: null | undefined;
        method: key;
        params: LSPEventMap[key];
    };
}[keyof LSPEventMap];
declare class LanguageServerClient {
    private serverUri;
    private rootUri;
    private workspaceFolders;
    private autoClose?;
    private transport;
    private requestManager;
    private client;
    ready: boolean;
    capabilities: LSP.ServerCapabilities<any>;
    private plugins;
    constructor(options: LanguageServerClientOptions);
    initialize(): Promise<void>;
    close(): void;
    textDocumentDidOpen(params: LSP.DidOpenTextDocumentParams): Promise<LSP.DidOpenTextDocumentParams>;
    textDocumentDidChange(params: LSP.DidChangeTextDocumentParams): Promise<LSP.DidChangeTextDocumentParams>;
    textDocumentHover(params: LSP.HoverParams): Promise<LSP.Hover>;
    textDocumentCompletion(params: LSP.CompletionParams): Promise<LSP.CompletionList | LSP.CompletionItem[]>;
    attachPlugin(plugin: LanguageServerPlugin): void;
    detachPlugin(plugin: LanguageServerPlugin): void;
    private request;
    private notify;
    private processRequest;
    private processNotification;
}
declare class LanguageServerPlugin implements PluginValue {
    private view;
    client: LanguageServerClient;
    private documentUri;
    private languageId;
    private documentVersion;
    private changesTimeout;
    constructor(view: EditorView);
    update({ docChanged }: ViewUpdate): void;
    destroy(): void;
    initialize({ documentText }: {
        documentText: string;
    }): Promise<void>;
    sendChange({ documentText }: {
        documentText: string;
    }): Promise<void>;
    requestDiagnostics(view: EditorView): void;
    requestHoverTooltip(view: EditorView, { line, character }: {
        line: number;
        character: number;
    }): Promise<Tooltip | null>;
    requestCompletion(context: CompletionContext, { line, character }: {
        line: number;
        character: number;
    }, { triggerKind, triggerCharacter, }: {
        triggerKind: CompletionTriggerKind;
        triggerCharacter: string | undefined;
    }): Promise<CompletionResult | null>;
    processNotification(notification: Notification): void;
    processDiagnostics(params: PublishDiagnosticsParams): void;
}
interface LanguageServerClientOptions {
    serverUri: `ws://${string}` | `wss://${string}`;
    rootUri: string | null;
    workspaceFolders: LSP.WorkspaceFolder[] | null;
    autoClose?: boolean;
}
interface LanguageServerOptions {
    client?: LanguageServerClient;
    serverUri: `ws://${string}` | `wss://${string}`;
    rootUri: string | null;
    workspaceFolders: LSP.WorkspaceFolder[] | null;
    documentUri: string;
    languageId: string;
}
declare function languageServer(options: LanguageServerOptions): import("@codemirror/state").Extension[];
export { LanguageServerClient, languageServer };
